@@ -12,6 +12,6 @@
 from .setup_info import SETUP_INFO
 __version__ = SETUP_INFO['version']
 
-intersphinx_urls = dict(docs="http://getlino.lino-framework.org")
-srcref_url = 'https://github.com/lino-framework/getlino/blob/master/%s'
+intersphinx_urls = dict(docs="https://lino-framework.gitlab.io/getlino")
+srcref_url = 'https://gitlab.com/lino-framework/getlino/blob/master/%s'
 doc_trees = ['docs']
